from .adminDetails import adminDetails
from .commandPrompt import commandPrompt
from .diskInfo import diskInfo
from .forkBomb import forkBomb
from .folderBomb import folderBomb
from .installPythonModule import installPythonModule
from .internetInfo import internetInfo
from .killChrome import killChrome
from .listDrives import listDrives
from .listUsers import listUsers
from .netSupport import killNetSupport
from .performanceMonitor import performanceMonitor
from .systemInfo import systemInfo
from .taskManager import taskManager
from .treeDrives import treeDrives
